@@ -1,6 +1,7 @@
 """Evergreen API Module."""
 # Shortcuts for importing.
 from evergreen.api import CachedEvergreenApi, EvergreenApi, Requester, RetryingEvergreenApi
+from evergreen.api_requests import IssueLinkRequest
 from evergreen.build import Build
 from evergreen.commitqueue import CommitQueue
 from evergreen.distro import Distro
@@ -10,6 +11,7 @@ from evergreen.patch import Patch
 from evergreen.project import Project
 from evergreen.stats import TaskStats, TestStats
 from evergreen.task import Task
+from evergreen.task_annotations import TaskAnnotation
 from evergreen.task_reliability import TaskReliability
 from evergreen.tst import Tst
 from evergreen.version import Version
